Development
===========

Quantities development uses the principles of test-driven development. New
features or bug fixes need to be accompanied by unit tests based on Python's
unittest package. Unit tests can be run with the following::

  pytest
